/**
******************************************************************************
* @file    Micro_controller_template.h
* @author  _KEMET, Ltd
* @date    March 2018
* @version Release 1.0.6
* @copyright (c) 2018 _KEMET, Ltd
* @brief   Public functions of Micro controller specific code to access the IRPyro sensor.
* @verbatim
===============================================================================
                  ##### How to use this template #####
===============================================================================
[..]
    This functions are referred on the IRPyro API, changing the names
    disables the API.
[..]

@endverbatim
******************************************************************************
   @attention <h2><center>&copy; COPYRIGHT 2018 _KEMET, Ltd</center></h2>

   @verbatim
    Copyright (c) 2018, _KEMET, Ltd
    All rights reserved.

    THIS SOFTWARE IS PROVIDED BY _KEMET, Ltd ''AS IS'' AND ANY
    EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
    WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
    DISCLAIMED. IN NO EVENT SHALL _KEMET, Ltd BE LIABLE FOR ANY
    DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
    (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
    LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
    ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
    (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
    SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
   @endverbatim
******************************************************************************
*/
/* Includes ------------------------------------------------------------------*/
#include <stddef.h>
#include <stdio.h>
#include <stdarg.h>
#include "stm32f30x.h"
#include "stm32f30x_exti.h"
#include "stm32f30x_gpio.h"
#include "stm32f30x_i2c.h"
#include "stm32f30x_syscfg.h"
#include "stm32f30x_usart.h"

/* Micro_controller_template function prototypes -----------------------------*/
void Micro_controller_template_init(void);
void Micro_controller_delay_ms(uint32_t time_ms);
void Micro_controller_delay_us(uint32_t time_us);
void Micro_controller_timeout_set(uint32_t timeout);
uint32_t Micro_controller_timeout_get(void);
void Micro_controller_delay_set(uint32_t delay);
uint32_t Micro_controller_delay_get(void);

/* GPIO Control Functions prototypes ******************************************/
uint8_t INT_pin_read(uint8_t port, uint8_t pin);
void    CS_pin_set(uint8_t port, uint8_t pin, uint8_t value);
void    power_set(uint8_t port, uint8_t pin);

typedef void (*EXTernal_callback)(void);
uint8_t EXTI_detected(uint8_t exti_line);
void EXTernal_Callback_Setup(EXTernal_callback Callback);

/* I2C Control Functions prototypes *******************************************/
uint8_t i2c_Write(uint8_t DeviceAddr , uint8_t Command, uint8_t* pBuffer, uint8_t len);
uint8_t i2c_Read(uint8_t    DeviceAddr, uint8_t Command, uint8_t* pBuffer, uint16_t len);

/* USART Control Function prototype *******************************************/
typedef void (*USART_callback)(void);
void USART_Callback_Tx_Setup(USART_callback Callback);
void USART_Callback_Rx_Setup(USART_callback Callback);
uint8_t UART_byte_get(void);
void UART_stream_binary_send(uint8_t *DataS);
void UART_stream_char_send(uint32_t *channel_value, uint8_t channel_saturation);
void UART_PutString(USART_TypeDef* USARTx, uint8_t * str);
void UART_PutNumber(USART_TypeDef* USARTx, uint32_t number);

/* Backplane Board control functions prototype *******************************************/
void Emitter_control(uint8_t *EmitterStatus, uint8_t EmitterONTime, uint8_t EmitterOFFTime);
void LED_READY(uint8_t LED_ready);

/* TIM control functions prototype *******************************************/
typedef void (*TIM_callback)(void);
void Micro_controller_sample_period_timer_set(uint32_t count_value);
uint32_t Micro_controller_sample_period_timer_get(void);
void TIM_Callback_Setup(TIM_callback Callback);
/* ********** Copyright (c) 2018 _KEMET, Ltd. **********END OF FILE************/
